@@ -538,9 +538,15 @@ sub Get {
 
 	# Setup authentication details, if necessary
 	if($self->{Proxy_Socket} ne '') {
-		my $ProxyUrl = "http://"."$self->{Proxy_User}".":"."$self->{Proxy_Password}"."@"."$self->{Proxy_Socket}";
-		$Browser->proxy(['http', 'ftp'], $ProxyUrl);
+		if($self->{Proxy_User} ne '') {
+			my $ProxyUrl = "http://"."$self->{Proxy_User}".":"."$self->{Proxy_Password}"."@"."$self->{Proxy_Socket}";
+			$Browser->proxy(['http', 'ftp'], $ProxyUrl);
+		}else{
+			my $ProxyUrl = "http://"."$self->{Proxy_Socket}";
+			$Browser->proxy(['http', 'ftp'], $ProxyUrl);		
+		}
 	}
+	
 	# if ($Browser->is_protocol_supported("ftp")) {print "ftp ok\n"}
 	my $result = $Browser->head($Url);
 	if ( ! $result->is_success ) {
